@@ -19,7 +19,7 @@ use URI::Escape;
 
 __PACKAGE__->mk_accessors(qw/apikey config/);
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 $VERSION = eval $VERSION;  # see L<perlmodstyle>
 
 # Preloaded methods go here.
@@ -42,16 +42,16 @@ sub new {
 
     return(undef,'missing config file') unless($args->{'config'} || $args->{'host'});
 
-    my $cfg;
+    my ($cfg, $clientcfg);
     
     if($args->{'config'}){
         $cfg = Config::Simple->new($args->{'config'}) || return(undef,'missing config file');
-        $cfg = $cfg->param(-block => 'client');
+        $clientcfg = $cfg->param(-block => 'client');
     }
 
-    my $apikey = $args->{'apikey'} || $cfg->{'apikey'};
+    my $apikey = $args->{'apikey'} || $clientcfg->{'apikey'};
     unless($args->{'host'}){
-        $args->{'host'} = $cfg->{'host'} || return(undef,'missing host');
+        $args->{'host'} = $clientcfg->{'host'} || return(undef,'missing host');
     }
 
     my $self = REST::Client->new($args);
@@ -59,19 +59,24 @@ sub new {
 
     $self->{'apikey'}           = $apikey;
     $self->{'config'}           = $cfg;
+    $self->{'clientconfig'}     = $clientcfg;
     $self->{'max_desc'}         = $args->{'max_desc'};
-    $self->{'restriction'}      = $cfg->{'restriction'};
-    $self->{'severity'}         = $cfg->{'severity'};
-    $self->{'nolog'}            = $cfg->{'nolog'};
-    $self->{'restriction'}      = $args->{'restriction'} || $cfg->{'restriction'};
-    $self->{'simple_hashes'}    = $args->{'simple_hashes'} || $cfg->{'simple_hashes'};
+    $self->{'restriction'}      = $clientcfg->{'restriction'};
+    $self->{'severity'}         = $clientcfg->{'severity'};
+    $self->{'nolog'}            = $clientcfg->{'nolog'};
+    $self->{'restriction'}      = $args->{'restriction'} || $clientcfg->{'restriction'};
+    $self->{'simple_hashes'}    = $args->{'simple_hashes'} || $clientcfg->{'simple_hashes'};
 
-    $self->{'verify_tls'}       = (defined($args->{'verify_tls'})) ? $args->{'verify_tls'} : $cfg->{'verify_tls'};
-    $self->{'guid'}             = $args->{'guid'} || $cfg->{'default_guid'};
-    $self->{'limit'}            = $args->{'limit'} || $cfg->{'limit'};
-    $self->{'group_map'}        = (defined($args->{'group_map'})) ? $args->{'group_map'} : $cfg->{'group_map'};
-    $self->{'compress_address'} = $args->{'compress_address'} || $cfg->{'compress_address'};
-    $self->{'round_confidence'} = $args->{'round_confidence'} || $cfg->{'round_confidence'};
+    $self->{'verify_tls'}       = (defined($args->{'verify_tls'})) ? $args->{'verify_tls'} : $clientcfg->{'verify_tls'};
+    $self->{'guid'}             = $args->{'guid'} || $clientcfg->{'default_guid'};
+    $self->{'limit'}            = $args->{'limit'} || $clientcfg->{'limit'};
+    $self->{'group_map'}        = (defined($args->{'group_map'})) ? $args->{'group_map'} : $clientcfg->{'group_map'};
+    $self->{'compress_address'} = $args->{'compress_address'} || $clientcfg->{'compress_address'};
+    $self->{'round_confidence'} = $args->{'round_confidence'} || $clientcfg->{'round_confidence'};
+    
+    $cfg->param('claoverride.compress_address', $args->{'compress_address'}) if $args->{'compress_address'};
+    $cfg->param('claoverride.round_confidence', $args->{'round_confidence'}) if $args->{'round_confidence'};
+    $cfg->param('claoverride.fields', $args->{'fields'}) if (exists $args->{'fields'} && defined($args->{'fields'}));
 
     $self->{'proxy'}            = $args->{'proxy'} || $cfg->{'proxy'};
     
@@ -111,7 +116,7 @@ sub GET {
         $q =~ s/\/$//g;
         ## escape unsafe chars, that's what the data-warehouse does
         ## TODO -- doc this
-        $q = uri_escape($q,'\x00-\x1f\x7f-\xff');
+        $q = uri_escape_utf8($q,'\x00-\x1f\x7f-\xff');
         $q = lc($q);
         $q = sha1_hex($q);
     }
